pub struct InstancePool { /* private fields */ }Expand description
Pool of WASM plugin instances.
Maintains a cache of compiled modules and manages instance creation.
Implementations
Sourceimpl InstancePool
impl InstancePool
Sourcepub fn new(engine: Arc<WasmEngine>, limits: PluginLimits) -> Self
pub fn new(engine: Arc<WasmEngine>, limits: PluginLimits) -> Self
Create a new instance pool.
Sourcepub fn with_http_client(
engine: Arc<WasmEngine>,
limits: PluginLimits,
http_client: Arc<HttpClient>,
) -> Self
pub fn with_http_client( engine: Arc<WasmEngine>, limits: PluginLimits, http_client: Arc<HttpClient>, ) -> Self
Create a new instance pool with an HTTP client for outbound calls.
Sourcepub fn with_http_client_and_secrets(
engine: Arc<WasmEngine>,
limits: PluginLimits,
http_client: Arc<HttpClient>,
secrets: SecretsStore,
) -> Self
pub fn with_http_client_and_secrets( engine: Arc<WasmEngine>, limits: PluginLimits, http_client: Arc<HttpClient>, secrets: SecretsStore, ) -> Self
Create a new instance pool with HTTP client and secrets store.
Sourcepub fn with_all_options(
engine: Arc<WasmEngine>,
limits: PluginLimits,
http_client: Option<Arc<HttpClient>>,
secrets: Option<SecretsStore>,
rate_limiter: Option<RateLimiter>,
response_cache: Option<ResponseCache>,
nats_publisher: Option<Arc<NatsPublisher>>,
kafka_publisher: Option<Arc<KafkaPublisher>>,
) -> Self
pub fn with_all_options( engine: Arc<WasmEngine>, limits: PluginLimits, http_client: Option<Arc<HttpClient>>, secrets: Option<SecretsStore>, rate_limiter: Option<RateLimiter>, response_cache: Option<ResponseCache>, nats_publisher: Option<Arc<NatsPublisher>>, kafka_publisher: Option<Arc<KafkaPublisher>>, ) -> Self
Create a new instance pool with all options.
Sourcepub fn register_module(&self, module: CompiledModule)
pub fn register_module(&self, module: CompiledModule)
Register a compiled module in the pool.
Sourcepub fn register_config(&self, key: InstanceKey, config_json: Vec<u8>)
pub fn register_config(&self, key: InstanceKey, config_json: Vec<u8>)
Register a plugin config.
Sourcepub fn get_instance(
&self,
key: &InstanceKey,
) -> Result<PluginInstance, WasmError>
pub fn get_instance( &self, key: &InstanceKey, ) -> Result<PluginInstance, WasmError>
Get or create an instance for the given key.
Sourcepub fn has_plugin(&self, name: &str) -> bool
pub fn has_plugin(&self, name: &str) -> bool
Check if a plugin is registered.
Sourcepub fn body_access(&self, name: &str) -> bool
pub fn body_access(&self, name: &str) -> bool
Check if a plugin has body_access capability.
Sourcepub fn module_count(&self) -> usize
pub fn module_count(&self) -> usize
Get the number of registered modules.
Sourcepub fn instance_key_count(&self) -> usize
pub fn instance_key_count(&self) -> usize
Get the number of registered instance keys.