pub struct MiddlewareChain { /* private fields */ }Expand description
A middleware chain that executes multiple middlewares in sequence.
Implementations
Sourceimpl MiddlewareChain
impl MiddlewareChain
Sourcepub fn from_configs(configs: Vec<MiddlewareConfig>) -> Self
pub fn from_configs(configs: Vec<MiddlewareConfig>) -> Self
Create a chain from a list of middleware configs.
Sourcepub fn push(&mut self, config: MiddlewareConfig)
pub fn push(&mut self, config: MiddlewareConfig)
Add a middleware to the chain.
Sourcepub fn configs(&self) -> &[MiddlewareConfig]
pub fn configs(&self) -> &[MiddlewareConfig]
Get the middleware configs.